<?php

namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\Libs\Util\NewCode;
use Teknisa\SM\Service\Sm00024000ParametrizacaoResultadoContratoMaoDeObraService as parametrizacaoMaoDeObraService ;


class Sm00024000ParametrizacaoResultadoContratoMaoDeObraController extends SMCrud {
    
    protected $dataSourceName = "fct_maoobracontctbl";
    protected $newCode;
    protected $parametrizacaoMaoDeObraService;
    
    public function __construct($crudService, $environment, NewCode $newCode, parametrizacaoMaoDeObraService $parametrizacaoMaoDeObraService) {
        parent::__construct($crudService, $environment);
        $this->newCode = $newCode;
        $this->parametrizacaoMaoDeObraService = $parametrizacaoMaoDeObraService;
    }
   

   /**
    *  Função que salva um registro de parametros de Mao de Obra pela pelo crud
    */

    public function save(Request $request, Response $response){
        try {

            $nrorg = $this->environment->getNrOrg();
            
            foreach ($request->getDataSet()->getRows() as &$row) {
                
              $row["NRMAOOBRACONTCTBL"] = $this->newCode->getCodeByTableName("FCT_MAOOBRACONTCTBL", $nrorg, 1, 10, true);

            }
            unset($row);
            
            parent::save($request, $response);
                
            
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
     /**
     *  A função "validar" que verifica se já existe mao de obra para o elemento Selecionado 
     *  que está salvo na widget de MaoDeObra.
     */
     
    public function validar(Request $request, Response $response){
        try {
            $row = $request->getRow();
            $cdservorca = $row["CDSERVORCA"];
            $cdcontctbl = $row["CDCONTCTBL"]; 
            $nrorg = $this->environment->getNrOrg();
            
            $resultado = $this->parametrizacaoMaoDeObraService->validar($cdservorca, $cdcontctbl, $nrorg);
            
            $response->addDataSet(
                new DataSet(
                    "validar", array(
                        "resultado" => $resultado
                    )
                )
            );
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}

?>

