<?php

namespace Teknisa\SM\Service;

use Teknisa\Libs\Util\Environment;
use Teknisa\SM\Factory\Sm00001000VendedorPropostaFactory;

class Sm00001000VendedorPropostaService {
    
    protected $vendedorPropostaFactory;
    
    public function __construct(Environment $environment, Sm00001000VendedorPropostaFactory $vendedorPropostaFactory) {
        $this->environment = $environment;
        $this->vendedorPropostaFactory = $vendedorPropostaFactory;
    }
    
    /**
     * Valida se o vendedor informado já existe.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrvendedororca
     * @param integer $nrparcvendedor
     */
    public function validarSeExisteVendedor($nrseqorcamento, $nrvendedororca, $nrparcvendedor) {
        $nrorg = $this->environment->getNrOrg();
        
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRVENDEDORORCA" => $nrvendedororca,
            "NRPARCVENDEDOR" => $nrparcvendedor,
            "NRORG"          => $nrorg
        );
        
        $dataset = $this->vendedorPropostaFactory->validarSeExisteVendedor($params);
        return ((int)$dataset[0]["EXISTE"] > 0);
    }
    
    /**
     * Valida se já existe um vendedor principal.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrvendedororca
     */
    public function validarSeExisteVendedorPrincipal($nrseqorcamento, $nrvendedororca) {
        $nrorg = $this->environment->getNrOrg();
        
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRVENDEDORORCA" => $nrvendedororca,
            "NRORG"          => $nrorg
        );
        
        $dataset = $this->vendedorPropostaFactory->validarSeExisteVendedorPrincipal($params);
        return ((int)$dataset[0]["EXISTE"] > 0);
    }
    
    /**
     * Retorna a soma da porcentagem na participação da venda dos vendedores da proposta.
     * 
     * @param integer $nrseqorcamento
     * @param integer $nrorg
     */
    public function getPorcentagemVendedores($nrseqorcamento, $nrorg) {
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg
        );
        
        $dataset = $this->vendedorPropostaFactory->getPorcentagemVendedores($params);
        return (float)$dataset[0]["VRPEPARTICIPAVENDA"];
    }
}

?>